# def test_read_csv():
#     csv_data = pd.read_csv('D:/workspace_cassandra/mmm/spedire/dataset-spedire-07-01-22.csv')
#     csv_data = csv_data[['ordine_data', 'revenue', 'transazioni', 'google_search_spent', 'google_performance_max_spent',
#                          'google_display_spent', 'fb_retargeting_spent', 'fb_prospecting_spent', 'bing_spent',
#                          'bing_organico', 'google_organico', 'referral', 'email_sessioni', 'cambio_eur_dollaro',
#                          'ios_14', 'Offerte']]
#
#     assert read_csv('D:/workspace_cassandra/mmm/spedire/dataset-spedire-07-01-22.csv',',',['ordine_data','revenue','transazioni','google_search_spent','google_performance_max_spent','google_display_spent','fb_retargeting_spent','fb_prospecting_spent','bing_spent','bing_organico','google_organico','referral','email_sessioni','cambio_eur_dollaro','ios_14','Offerte'],[]) == csv_data
